@@ -5,7 +5,7 @@ use Carp qw(cluck carp confess);
 #$SIG{__WARN__} = sub { cluck $_[0] };
 #$SIG{__DIE__} = sub { confess "[". $_[0] ."]"};
 
-my $bus = Net::DBus->find();
+my $bus = Net::DBus->session();
 
 my $service = $bus->get_service("org.designfu.SampleService");
 my $object = $service->get_object("/SomeObject");
