@@ -53,7 +53,7 @@ sub GetTuple {
 
 package main;
 
-my $bus = Net::DBus->find();
+my $bus = Net::DBus->session();
 my $service = $bus->export_service("org.designfu.SampleService");
 my $object = SomeObject->new($service);
 
